==> spincast-plugins-crypto-0.9.46-sources.jar: org/spincast/plugins/crypto/SpincastCryptoUtils.java <==
package org.spincast.plugins.crypto;

import org.spincast.plugins.crypto.config.SpincastCryptoConfig;

/**
 * Spincast Crypto utils
 */
public interface SpincastCryptoUtils {

    /**
     * Encrypts a string, using the given secrte key and the 
     * <code>AES</code> algorithm. 
     * <p>
     * The generated encrypted payload
     * is a string which is also base64 encoded so it can be
     * used in urls, emails, etc.
     * <p>
     * You must use the associated {@link #decrypt(String, String)} method to decrypt
     * the resultind payload. 
     * <p>
     * <strong>IMPORTANT!</strong>: For this method to work,
     * JCE policy files may  be installed first, security must
     * be configured properly, or security policy must be
     * disabled using the {@link SpincastCryptoConfig#removeJavaCryptoRestrictionsOnInit()}
     * configuration.
     * <p>
     * <a href="https://stackoverflow.com/questions/1179672/how-to-avoid-installing-unlimited-strength-jce-policy-files-when-deploying-an">more info</a>
     */
    public String encrypt(String toEncrypt, String secretKey);

    /**
     * Decrypts a string that was encrypted using 
     * {@link #encrypt(String, String)}.
     * <p>
     * <strong>IMPORTANT!</strong>: For this method to work,
     * JCE policy files may  be installed first, security must
     * be configured properly, or security policy must be
     * disabled using the {@link SpincastCryptoConfig#removeJavaCryptoRestrictionsOnInit()}
     * configuration.
     * <p>
     * <a href="https://stackoverflow.com/questions/1179672/how-to-avoid-installing-unlimited-strength-jce-policy-files-when-deploying-an">more info</a>
     */
    public String decrypt(String payload, String secretKey);


    /**
     * Tries to remove the Java cryptography restrictions.
     * <p>
     * @see https://stackoverflow.com/a/22492582/843699
     * 
     * @throws an Exception is the restrictions can't be removed.
     */
    public void removeCryptographyRestrictions() throws RuntimeException;

    /**
     * Is the current Java version cryptography restricted?
     */
    public boolean isRestrictedCryptographyJavaVersion();
}

==> spincast-plugins-crypto-2.0.0-sources.jar: org/spincast/plugins/crypto/SpincastCryptoUtils.java <==
package org.spincast.plugins.crypto;

import org.spincast.plugins.crypto.config.SpincastCryptoConfig;

/**
 * Spincast Crypto utils
 */
public interface SpincastCryptoUtils {

    /**
     * Encrypts a string, using the given secret key and the 
     * <code>AES</code> algorithm. 
     * <p>
     * The generated encrypted payload
     * is a string which is also base64 encoded so it can be
     * used in urls, emails, etc.
     * <p>
     * You must use the associated {@link #decrypt(String, String)} method to decrypt
     * the resultind payload. 
     * <p>
     * <strong>IMPORTANT!</strong>: For this method to work,
     * JCE policy files may  be installed first, security must
     * be configured properly, or security policy must be
     * disabled using the {@link SpincastCryptoConfig#removeJavaCryptoRestrictionsOnInit()}
     * configuration.
     * <p>
     * <a href="https://stackoverflow.com/questions/1179672/how-to-avoid-installing-unlimited-strength-jce-policy-files-when-deploying-an">more info</a>
     */
    public String encrypt(String toEncrypt, String secretKey);

    /**
     * Decrypts a string that was encrypted using 
     * {@link #encrypt(String, String)}.
     * <p>
     * <strong>IMPORTANT!</strong>: For this method to work,
     * JCE policy files may  be installed first, security must
     * be configured properly, or security policy must be
     * disabled using the {@link SpincastCryptoConfig#removeJavaCryptoRestrictionsOnInit()}
     * configuration.
     * <p>
     * <a href="https://stackoverflow.com/questions/1179672/how-to-avoid-installing-unlimited-strength-jce-policy-files-when-deploying-an">more info</a>
     */
    public String decrypt(String payload, String secretKey);

    /**
     * Will hash a string using <code>BCrypt</code>. This is currently
     * a good way to hash passwords so they can be stored in a database.
     * <p>
     * You can use {@link #generateNewHashSecureSalt()} to generate a
     * new salt.
     */
    public String hashSecure(String toHash, String salt);

    /**
     * Will generate a new secure salt that can
     * be used with
     * {@link #hashSecure(String, String)}.
     */
    public String generateNewHashSecureSalt();

    /**
     * Tries to remove the Java cryptography restrictions.
     * <p>
     * @see https://stackoverflow.com/a/22492582/843699
     * 
     * @throws an Exception is the restrictions can't be removed.
     */
    public void removeCryptographyRestrictions() throws RuntimeException;

    /**
     * Is the current Java version cryptography restricted?
     */
    public boolean isRestrictedCryptographyJavaVersion();
}
